"use client";

import useFormSubmission from "@/hooks/use-form-submission";
import { selectStructureType } from "@/servers/actions/pool-request-action";
import { useTranslations } from "next-intl";
import { useRouter } from "next/navigation";
import { Suspense } from "react";
import FormButtons from "../common/form-buttons";
import StructureOptions from "./structure-options";
import StructureOptionsSkeleton from "./structure-options-skeleton";


// Server action for structure selection
async function handleStructureSelect(formData: FormData, messages: { success: string, error: string, missing: string }) {
	const structureType = formData.get("structureType");

	if (!structureType) {
		// Handle error case
		return { success: false, message: messages.missing };
	}

	const response = await selectStructureType({ structure_type: structureType as string });
	console.log("response: ", response);
	if (response.success) {
		// Return success status instead of showing toast directly
		return { success: true, message: messages.success };
	} else {
		// Handle error case
		return { success: false, message: response.message || messages.error };
	}
}

// Client component to handle toast notifications
function StructureTypeFormClient() {
	const t = useTranslations();
	const router = useRouter();

	const messages = {
		success: t("The structure type has been saved successfully"),
		error: t("Failed to save structure type"),
		missing: t("Please select a structure type")
	};

	const { handleSubmit, handleNextClick, isPending, isNextPending } = useFormSubmission(
		handleStructureSelect,
		messages,
		"/simulation-program/design-type"
	);

	return (
		<form action={handleSubmit}>
			<div className="border-[1px] rounded-md p-2 w-[800px] backdrop-blur-md">
				<Suspense fallback={<StructureOptionsSkeleton />}>
					<StructureOptions isPending={isPending} />
				</Suspense>
			</div>
			<FormButtons
				onPrevious={() => router.back()}
				onNext={handleNextClick}
				isPending={isNextPending}
			/>
		</form>
	);
}

// Server component that renders the client component
export default function StructureTypeForm() {
	return <StructureTypeFormClient />;
} 